==> OneHitWonder_v0.015.zip: Interface/AddOns/OneHitWonder/localization_Spells.lua <==
-- Version : English - sarf
-- Translation by : None

-- Tracking Spells

ONEHITWONDER_ABILITY_FIND_HERBS_NAME			= "Find Herbs";
ONEHITWONDER_ABILITY_FIND_MINERALS_NAME			= "Find Minerals";
ONEHITWONDER_ABILITY_FIND_TREASURE_NAME			= "Find Treasure";
ONEHITWONDER_ABILITY_SENSE_DEMONS_NAME			= "Sense Demons";
ONEHITWONDER_ABILITY_SENSE_UNDEAD_NAME			= "Sense Undead";
ONEHITWONDER_ABILITY_TRACK_BEASTS_NAME			= "Track Beasts";
ONEHITWONDER_ABILITY_TRACK_HUMANOIDS_NAME		= "Track Humanoids";
ONEHITWONDER_ABILITY_TRACK_UNDEAD_NAME			= "Track Undead";
ONEHITWONDER_ABILITY_TRACK_HIDDEN_NAME			= "Track Hidden";
ONEHITWONDER_ABILITY_TRACK_ELEMENTALS_NAME		= "Track Elementals";
ONEHITWONDER_ABILITY_TRACK_HUMANOID_NAME		= "Track Humanoid";
ONEHITWONDER_ABILITY_TRACK_DEMONS_NAME			= "Track Demons";
ONEHITWONDER_ABILITY_TRACK_GIANTS_NAME			= "Track Giants";
ONEHITWONDER_ABILITY_TRACK_DRAGONKIN_NAME		= "Track Dragonkin";


-- Druid Spells

ONEHITWONDER_ABILITY_MARK_OF_THE_WILD_NAME = "Mark of the Wild";
ONEHITWONDER_ABILITY_THORNS_NAME = "Thorns";

-- Hunter Attack

ONEHITWONDER_ABILITY_COUNTERATTACK_NAME = "Counterattack";
ONEHITWONDER_ABILITY_MONGOOSE_BITE_NAME = "Mongoose Bite";

-- Mage Spells

ONEHITWONDER_SPELL_MANA_SHIELD_NAME = "Mana Shield";
ONEHITWONDER_SPELL_MANA_SHIELD_EFFECT = "Mana Shield";
ONEHITWONDER_SPELL_FROST_WARD_NAME = "Frost Ward";
ONEHITWONDER_SPELL_FIRE_WARD_NAME = "Fire Ward";

ONEHITWONDER_SPELL_DAMPEN_MAGIC_NAME = "Dampen Magic";

ONEHITWONDER_SPELL_ARCANE_INTELLECT_NAME = "Arcane Intellect";
ONEHITWONDER_SPELL_FROST_ARMOR_NAME = "Frost Armor";
ONEHITWONDER_SPELL_ICE_ARMOR_NAME = "Ice Armor";

-- Paladin Spells

ONEHITWONDER_SPELL_HAMMER_OF_JUSTICE_NAME = "Hammer of Justice";

ONEHITWONDER_SPELL_BLESSING_OF_KINGS_NAME = "Blessing of Kings";
ONEHITWONDER_SPELL_BLESSING_OF_LIGHT_NAME = "Blessing of Light";
ONEHITWONDER_SPELL_BLESSING_OF_MIGHT_NAME = "Blessing of Might";
ONEHITWONDER_SPELL_BLESSING_OF_FREEDOM_NAME = "Blessing of Freedom";
ONEHITWONDER_SPELL_BLESSING_OF_PROTECTION_NAME = "Blessing of Protection";
ONEHITWONDER_SPELL_BLESSING_OF_SANCTUARY_NAME = "Blessing of Sanctuary";
ONEHITWONDER_SPELL_BLESSING_OF_SALVATION_NAME = "Blessing of Salvation";
ONEHITWONDER_SPELL_BLESSING_OF_SACRIFICE_NAME = "Blessing of Sacrifice";
ONEHITWONDER_SPELL_BLESSING_OF_WISDOM_NAME = "Blessing of Wisdom";

ONEHITWONDER_SPELL_JUDGEMENT_NAME = "Judgement";

ONEHITWONDER_SPELL_SEAL_OF_COMMAND_NAME = "Seal of Command";
ONEHITWONDER_SPELL_SEAL_OF_FURY_NAME = "Seal of Fury";
ONEHITWONDER_SPELL_SEAL_OF_JUSTICE_NAME = "Seal of Justice";
ONEHITWONDER_SPELL_SEAL_OF_LIGHT_NAME = "Seal of Light";
ONEHITWONDER_SPELL_SEAL_OF_RIGHTEOUSNESS_NAME = "Seal of Righteousness";
ONEHITWONDER_SPELL_SEAL_OF_THE_CRUSADER_JUDGEMENT_EFFECT = "Judgement of the Crusader";
ONEHITWONDER_SPELL_SEAL_OF_THE_CRUSADER_NAME = "Seal of the Crusader";
ONEHITWONDER_SPELL_SEAL_OF_WISDOM_NAME = "Seal of Wisdom";

-- Priest Spells

ONEHITWONDER_ABILITY_POWER_WORD_FORTITUDE_NAME = "Power Word: Fortitude";
ONEHITWONDER_ABILITY_INNER_FIRE_NAME = "Inner Fire";

-- Rogue Spells

ONEHITWONDER_ABILITY_STEALTH_NAME = "Stealth";
ONEHITWONDER_ABILITY_STEALTH_EFFECT = "Stealth";
ONEHITWONDER_ABILITY_VANISH_NAME = "Vanish";
ONEHITWONDER_ABILITY_VANISH_EFFECT = "Vanish";
ONEHITWONDER_ABILITY_SLICEDICE_EFFECT = "Slice and Dice";
ONEHITWONDER_ABILITY_EXPOSEARMOR_EFFECT = "Expose Armor";

ONEHITWONDER_ABILITY_EXPOSEARMOR_NAME = "Expose Armor";
ONEHITWONDER_ABILITY_AMBUSH_NAME = "Ambush";
ONEHITWONDER_ABILITY_GOUGE_NAME = "Gouge";
ONEHITWONDER_ABILITY_BACKSTAB_NAME = "Backstab";
ONEHITWONDER_ABILITY_EVISCERATE_NAME = "Eviscerate";
ONEHITWONDER_ABILITY_SLICEDICE_NAME = "Slice and Dice";
ONEHITWONDER_ABILITY_SINISTERSTRIKE_NAME = "Sinister Strike";
ONEHITWONDER_ABILITY_PICKPOCKET_NAME = "Pick Pocket";
ONEHITWONDER_ABILITY_KICK_NAME = "Kick";
ONEHITWONDER_ABILITY_FEINT_NAME = "Feint";
ONEHITWONDER_ABILITY_RUPTURE_NAME = "Rupture";
ONEHITWONDER_ABILITY_DISTRACT_NAME = "Distract";
ONEHITWONDER_ABILITY_GARROTTE_NAME = "Garrotte";
ONEHITWONDER_ABILITY_CHEAPSHOT_NAME = "Cheap Shot";
ONEHITWONDER_ABILITY_KIDNEYSHOT_NAME = "Kidney Shot";

ONEHITWONDER_TALENT_RIPOSTE_NAME = "Riposte";

-- Shaman Spells

ONEHITWONDER_SPELL_LIGHTNING_SHIELD_NAME = "Lightning Shield";
ONEHITWONDER_SPELL_EARTHSHOCK_NAME = "Earth Shock";

-- Warlock Spells

ONEHITWONDER_SPELL_DRAIN_SOUL = "Drain Soul";

ONEHITWONDER_SPELL_IMMOLATE = "Immolate";
ONEHITWONDER_EFFECT_IMMOLATE = "Immolate";

ONEHITWONDER_SPELL_CORRUPTION = "Corruption";
ONEHITWONDER_EFFECT_CORRUPTION = "Corruption";

ONEHITWONDER_SPELL_SHADOW_BOLT = "Shadow Bolt";

ONEHITWONDER_SPELL_SHADOWBURN = "Shadowburn";

ONEHITWONDER_SPELL_SOUL_FIRE = "Soul Fire";

ONEHITWONDER_SPELL_CURSE_AGONY = "Curse of Agony";
ONEHITWONDER_SPELL_CURSE_DOOM = "Curse of Doom";
ONEHITWONDER_SPELL_CURSE_ELEMENTS = "Curse of the Elements";
ONEHITWONDER_SPELL_CURSE_RECKLESSNESS = "Curse of Recklessness";
ONEHITWONDER_SPELL_CURSE_SHADOW = "Curse of Shadow";
ONEHITWONDER_SPELL_CURSE_TONGUES = "Curse of Tongues";
ONEHITWONDER_SPELL_CURSE_WEAKNESS = "Curse of Weakness";

ONEHITWONDER_EFFECT_CURSE_AGONY = "Curse of Agony";
ONEHITWONDER_EFFECT_CURSE_TONGUES = "Curse of Tongues";
ONEHITWONDER_EFFECT_CURSE_RECKLESSNESS = "Curse of Recklessness";

-- Warrior Spells

ONEHITWONDER_WARRIOR_STANCE_BATTLE_NAME = "Battle Stance";
ONEHITWONDER_WARRIOR_STANCE_DEFENSIVE_NAME = "Defensive Stance";
ONEHITWONDER_WARRIOR_STANCE_AGGRESSIVE_NAME = "Berserk Stance";
ONEHITWONDER_WARRIOR_STANCE_BERZERK_NAME = "Unknown Stance";


ONEHITWONDER_ABILITY_PUMMEL_NAME = "Pummel";
ONEHITWONDER_ABILITY_SHIELDBASH_NAME = "Shield Bash";
ONEHITWONDER_ABILITY_REVENGE_NAME = "Revenge";
ONEHITWONDER_ABILITY_HEROICSTRIKE_NAME = "Heroic Strike";
ONEHITWONDER_ABILITY_REND_NAME = "Rend";
ONEHITWONDER_ABILITY_CHARGE_NAME = "Charge";
ONEHITWONDER_ABILITY_BATTLESHOUT_NAME = "Battle Shout";
ONEHITWONDER_ABILITY_HAMSTRING_NAME = "Hamstring";
ONEHITWONDER_ABILITY_MOCKINGBLOW_NAME = "Mocking Blow";
ONEHITWONDER_ABILITY_OVERPOWER_NAME = "Overpower";

-- Miscellaneous Spells

ONEHITWONDER_ABILITY_SHOOT_NAME = "Shoot";
ONEHITWONDER_ABILITY_SHOOT_EFFECT = "Shoot"; -- ?

-- Race Spells

ONEHITWONDER_ABILITY_BERSERK_NAME = "Berserk";



if ( GetLocale() == "frFR" ) then
elseif ( GetLocale() == "deDE" ) then
end

==> OneHitWonder_v0.016.zip: Interface/AddOns/OneHitWonder/localization_Spells.lua <==
-- Version : English - sarf
-- Translation by : None

-- Tracking Spells

ONEHITWONDER_ABILITY_FIND_HERBS_NAME			= "Find Herbs";
ONEHITWONDER_ABILITY_FIND_MINERALS_NAME			= "Find Minerals";
ONEHITWONDER_ABILITY_FIND_TREASURE_NAME			= "Find Treasure";
ONEHITWONDER_ABILITY_SENSE_DEMONS_NAME			= "Sense Demons";
ONEHITWONDER_ABILITY_SENSE_UNDEAD_NAME			= "Sense Undead";
ONEHITWONDER_ABILITY_TRACK_BEASTS_NAME			= "Track Beasts";
ONEHITWONDER_ABILITY_TRACK_HUMANOIDS_NAME		= "Track Humanoids";
ONEHITWONDER_ABILITY_TRACK_UNDEAD_NAME			= "Track Undead";
ONEHITWONDER_ABILITY_TRACK_HIDDEN_NAME			= "Track Hidden";
ONEHITWONDER_ABILITY_TRACK_ELEMENTALS_NAME		= "Track Elementals";
ONEHITWONDER_ABILITY_TRACK_HUMANOID_NAME		= "Track Humanoid";
ONEHITWONDER_ABILITY_TRACK_DEMONS_NAME			= "Track Demons";
ONEHITWONDER_ABILITY_TRACK_GIANTS_NAME			= "Track Giants";
ONEHITWONDER_ABILITY_TRACK_DRAGONKIN_NAME		= "Track Dragonkin";


-- Druid Spells

ONEHITWONDER_ABILITY_MARK_OF_THE_WILD_NAME = "Mark of the Wild";
ONEHITWONDER_ABILITY_THORNS_NAME = "Thorns";

ONEHITWONDER_SPELL_REMOVE_CURSE_NAME = "Remove Curse";

-- Hunter Attack

ONEHITWONDER_ABILITY_COUNTERATTACK_NAME = "Counterattack";
ONEHITWONDER_ABILITY_MONGOOSE_BITE_NAME = "Mongoose Bite";


ONEHITWONDER_SPELL_ASPECT_OF_THE_HAWK_NAME = "Aspect of the Hawk";
ONEHITWONDER_SPELL_ASPECT_OF_THE_MONKEY_NAME = "Aspect of the Monkey";
ONEHITWONDER_SPELL_ASPECT_OF_THE_CHEETAH_NAME = "Aspect of the Cheetah";
ONEHITWONDER_SPELL_ASPECT_OF_THE_BEAST_NAME = "Aspect of the Beast";
ONEHITWONDER_SPELL_ASPECT_OF_THE_PACK_NAME = "Aspect of the Pack";
ONEHITWONDER_SPELL_ASPECT_OF_THE_WILD_NAME = "Aspect of the Wild";


-- Mage Spells

ONEHITWONDER_SPELL_REMOVE_LESSER_CURSE_NAME = "Remove Lesser Curse";

ONEHITWONDER_SPELL_MANA_SHIELD_NAME = "Mana Shield";
ONEHITWONDER_SPELL_MANA_SHIELD_EFFECT = "Mana Shield";
ONEHITWONDER_SPELL_FROST_WARD_NAME = "Frost Ward";
ONEHITWONDER_SPELL_FIRE_WARD_NAME = "Fire Ward";

ONEHITWONDER_SPELL_DAMPEN_MAGIC_NAME = "Dampen Magic";

ONEHITWONDER_SPELL_ARCANE_INTELLECT_NAME = "Arcane Intellect";
ONEHITWONDER_SPELL_FROST_ARMOR_NAME = "Frost Armor";
ONEHITWONDER_SPELL_ICE_ARMOR_NAME = "Ice Armor";

ONEHITWONDER_LESSER_CURSE_NAMES = {
	"Haunted",
};

-- Paladin Spells

ONEHITWONDER_SPELL_CLEANSE_NAME = "Cleanse";
ONEHITWONDER_SPELL_PURIFY_NAME = "Purify";


ONEHITWONDER_SPELL_AURA_SUBSTRING = "Aura";
ONEHITWONDER_SPELL_BLESSING_SUBSTRING = "Blessing";


ONEHITWONDER_SPELL_DEVOTION_AURA_NAME = "Devotion Aura";
ONEHITWONDER_SPELL_DEVOTION_AURA_EFFECT = "Devotion Aura";

ONEHITWONDER_SPELL_HAMMER_OF_JUSTICE_NAME = "Hammer of Justice";

ONEHITWONDER_SPELL_BLESSING_OF_KINGS_NAME = "Blessing of Kings";
ONEHITWONDER_SPELL_BLESSING_OF_LIGHT_NAME = "Blessing of Light";
ONEHITWONDER_SPELL_BLESSING_OF_MIGHT_NAME = "Blessing of Might";
ONEHITWONDER_SPELL_BLESSING_OF_FREEDOM_NAME = "Blessing of Freedom";
ONEHITWONDER_SPELL_BLESSING_OF_PROTECTION_NAME = "Blessing of Protection";
ONEHITWONDER_SPELL_BLESSING_OF_SANCTUARY_NAME = "Blessing of Sanctuary";
ONEHITWONDER_SPELL_BLESSING_OF_SALVATION_NAME = "Blessing of Salvation";
ONEHITWONDER_SPELL_BLESSING_OF_SACRIFICE_NAME = "Blessing of Sacrifice";
ONEHITWONDER_SPELL_BLESSING_OF_WISDOM_NAME = "Blessing of Wisdom";

ONEHITWONDER_SPELL_JUDGEMENT_NAME = "Judgement";

ONEHITWONDER_SPELL_SEAL_OF_COMMAND_NAME = "Seal of Command";
ONEHITWONDER_SPELL_SEAL_OF_FURY_NAME = "Seal of Fury";
ONEHITWONDER_SPELL_SEAL_OF_JUSTICE_NAME = "Seal of Justice";
ONEHITWONDER_SPELL_SEAL_OF_LIGHT_NAME = "Seal of Light";
ONEHITWONDER_SPELL_SEAL_OF_RIGHTEOUSNESS_NAME = "Seal of Righteousness";
ONEHITWONDER_SPELL_SEAL_OF_THE_CRUSADER_JUDGEMENT_EFFECT = "Judgement of the Crusader";
ONEHITWONDER_SPELL_SEAL_OF_THE_CRUSADER_NAME = "Seal of the Crusader";
ONEHITWONDER_SPELL_SEAL_OF_WISDOM_NAME = "Seal of Wisdom";

-- Priest Spells

ONEHITWONDER_ABILITY_POWER_WORD_FORTITUDE_NAME = "Power Word: Fortitude";
ONEHITWONDER_ABILITY_INNER_FIRE_NAME = "Inner Fire";

ONEHITWONDER_SPELL_CURE_DISEASE_NAME = "Cure Disease";
ONEHITWONDER_SPELL_ABOLISH_DISEASE_NAME = "Abolish Disease";


-- Rogue Spells

ONEHITWONDER_ABILITY_DETECT_TRAPS_NAME = "Detect Traps";
ONEHITWONDER_ABILITY_DETECT_TRAPS_EFFECT = "Detect Traps";

ONEHITWONDER_ABILITY_STEALTH_NAME = "Stealth";
ONEHITWONDER_ABILITY_STEALTH_EFFECT = "Stealth";
ONEHITWONDER_ABILITY_VANISH_NAME = "Vanish";
ONEHITWONDER_ABILITY_VANISH_EFFECT = "Vanish";
ONEHITWONDER_ABILITY_SLICEDICE_EFFECT = "Slice and Dice";
ONEHITWONDER_ABILITY_EXPOSEARMOR_EFFECT = "Expose Armor";

ONEHITWONDER_ABILITY_EXPOSEARMOR_NAME = "Expose Armor";
ONEHITWONDER_ABILITY_AMBUSH_NAME = "Ambush";
ONEHITWONDER_ABILITY_GOUGE_NAME = "Gouge";
ONEHITWONDER_ABILITY_BACKSTAB_NAME = "Backstab";
ONEHITWONDER_ABILITY_EVISCERATE_NAME = "Eviscerate";
ONEHITWONDER_ABILITY_SLICEDICE_NAME = "Slice and Dice";
ONEHITWONDER_ABILITY_SINISTERSTRIKE_NAME = "Sinister Strike";
ONEHITWONDER_ABILITY_PICKPOCKET_NAME = "Pick Pocket";
ONEHITWONDER_ABILITY_KICK_NAME = "Kick";
ONEHITWONDER_ABILITY_FEINT_NAME = "Feint";
ONEHITWONDER_ABILITY_RUPTURE_NAME = "Rupture";
ONEHITWONDER_ABILITY_DISTRACT_NAME = "Distract";
ONEHITWONDER_ABILITY_GARROTTE_NAME = "Garrotte";
ONEHITWONDER_ABILITY_CHEAPSHOT_NAME = "Cheap Shot";
ONEHITWONDER_ABILITY_KIDNEYSHOT_NAME = "Kidney Shot";

ONEHITWONDER_TALENT_RIPOSTE_NAME = "Riposte";

-- Shaman Spells

ONEHITWONDER_SPELL_LIGHTNING_SHIELD_NAME = "Lightning Shield";
ONEHITWONDER_SPELL_EARTHSHOCK_NAME = "Earth Shock";
ONEHITWONDER_SPELL_GROUNDING_TOTEM_NAME = "Grounding Totem";

ONEHITWONDER_SPELL_WINDFURY_WEAPON_NAME = "Windfury Weapon";
ONEHITWONDER_SPELL_ROCKBITER_WEAPON_NAME = "Rockbiter Weapon";
ONEHITWONDER_SPELL_FLAMETONGUE_WEAPON_NAME = "Flametongue Weapon";
ONEHITWONDER_SPELL_FROSTBRAND_WEAPON_NAME = "Frostbrand Weapon";

ONEHITWONDER_SPELL_WINDFURY_WEAPON_EFFECT = "Windfury";
ONEHITWONDER_SPELL_ROCKBITER_WEAPON_EFFECT = "Rockbiter";
ONEHITWONDER_SPELL_FLAMETONGUE_WEAPON_EFFECT = "Flametongue";
ONEHITWONDER_SPELL_FROSTBRAND_WEAPON_EFFECT = "Frostbrand";


-- Warlock Spells

ONEHITWONDER_SPELL_DEMON_SKIN_NAME = "Demon Skin";
ONEHITWONDER_SPELL_DEMON_ARMOR_NAME = "Demon Armor";

ONEHITWONDER_SPELL_DETECT_LESSER_INVISIBILITY_NAME = "Detect Lesser Invisibility";
ONEHITWONDER_SPELL_DETECT_INVISIBILITY_NAME = "Detect Invisibility";
ONEHITWONDER_SPELL_DETECT_GREATER_INVISIBILITY_NAME = "Detect Greater Invisibility";


ONEHITWONDER_SPELL_DRAIN_SOUL = "Drain Soul";

ONEHITWONDER_SPELL_IMMOLATE = "Immolate";
ONEHITWONDER_EFFECT_IMMOLATE = "Immolate";

ONEHITWONDER_SPELL_CONFLAGRATE = "Conflagrate";

ONEHITWONDER_SPELL_CORRUPTION = "Corruption";
ONEHITWONDER_EFFECT_CORRUPTION = "Corruption";

ONEHITWONDER_SPELL_SHADOW_BOLT = "Shadow Bolt";

ONEHITWONDER_SPELL_SHADOWBURN = "Shadowburn";

ONEHITWONDER_SPELL_SOUL_FIRE = "Soul Fire";

ONEHITWONDER_SPELL_CURSE_AGONY = "Curse of Agony";
ONEHITWONDER_SPELL_CURSE_DOOM = "Curse of Doom";
ONEHITWONDER_SPELL_CURSE_ELEMENTS = "Curse of the Elements";
ONEHITWONDER_SPELL_CURSE_RECKLESSNESS = "Curse of Recklessness";
ONEHITWONDER_SPELL_CURSE_SHADOW = "Curse of Shadow";
ONEHITWONDER_SPELL_CURSE_TONGUES = "Curse of Tongues";
ONEHITWONDER_SPELL_CURSE_WEAKNESS = "Curse of Weakness";

ONEHITWONDER_EFFECT_CURSE_AGONY = "Curse of Agony";
ONEHITWONDER_EFFECT_CURSE_TONGUES = "Curse of Tongues";
ONEHITWONDER_EFFECT_CURSE_RECKLESSNESS = "Curse of Recklessness";

-- Warrior Spells

ONEHITWONDER_WARRIOR_STANCE_BATTLE_NAME = "Battle Stance";
ONEHITWONDER_WARRIOR_STANCE_DEFENSIVE_NAME = "Defensive Stance";
ONEHITWONDER_WARRIOR_STANCE_AGGRESSIVE_NAME = "Berserk Stance";
ONEHITWONDER_WARRIOR_STANCE_BERZERK_NAME = "Unknown Stance";


ONEHITWONDER_ABILITY_PUMMEL_NAME = "Pummel";
ONEHITWONDER_ABILITY_SHIELDBASH_NAME = "Shield Bash";
ONEHITWONDER_ABILITY_REVENGE_NAME = "Revenge";
ONEHITWONDER_ABILITY_HEROICSTRIKE_NAME = "Heroic Strike";
ONEHITWONDER_ABILITY_REND_NAME = "Rend";
ONEHITWONDER_ABILITY_CHARGE_NAME = "Charge";
ONEHITWONDER_ABILITY_BATTLESHOUT_NAME = "Battle Shout";
ONEHITWONDER_ABILITY_HAMSTRING_NAME = "Hamstring";
ONEHITWONDER_ABILITY_MOCKINGBLOW_NAME = "Mocking Blow";
ONEHITWONDER_ABILITY_OVERPOWER_NAME = "Overpower";

-- Miscellaneous Spells

ONEHITWONDER_ABILITY_SHOOT_NAME = "Shoot";
ONEHITWONDER_ABILITY_SHOOT_EFFECT = "Shoot"; -- ?

-- Race Spells

ONEHITWONDER_ABILITY_BERSERK_NAME = "Berserk";


-- Debuff Types

ONEHITWONDER_DEBUFF_TYPE_CURSE_LESSER	= "Lesser";

ONEHITWONDER_DEBUFF_TYPE_CURSE			= "Curse";
ONEHITWONDER_DEBUFF_TYPE_POISON			= "Poison";
ONEHITWONDER_DEBUFF_TYPE_DISEASE		= "Disease";

-- Spell lists

OneHitWonder_ShadowSpells = {
	"shadow bolt",
	"shadowburn",
	"mind blast",
	"touch of weakness",
	"devouring plague",
	"shadow word: pain",
	"mind flay"
};

OneHitWonder_ShadowSpellKeyWords = {
	"shadow",
	"dark",
	"consuming"
};

OneHitWonder_NotShadowSpells = {
	"shadow resistance aura", -- once again... not truly correct
	"shadow protection",
	"shadow ward",
	"shadowguard", -- debatable
	"curse of shadow", -- also debatable
	"dark pact",
	"mind soothe",
	"mind-numbing poison",
	"mind control", -- not entirely true
	"mind vision"
};

OneHitWonder_FireSpells = {
	"fireball",
	"fire blast",
	"fire nova totem",
	"rain of fire",
	"holy fire",
	"hellfire",
	"searing pain",
	"soul fire",
	"pyroblast",
	"scorch",
	"immolate",
	"torch burst"
};

OneHitWonder_NotFireSpells = {
	"moonfire",
	"faerie fire",
	"fire ward", -- not really true, but used in the context it will be...
	"starfire",
	"rapid fire",
	"fire resistance totem",
	"inner fire",
	"searing totem"
};

OneHitWonder_FireSpellKeyWords = {
	"pyro",
	"fire",
	"searing",
	"scorch"
};

OneHitWonder_FrostSpells = {
	"frostbolt",
	"frost nova", -- should this be here or in not frost spells? we can't do anything, so...
	"frostbrand weapon",
	"cone of cold",
	"blizzard"
};

OneHitWonder_FrostSpellKeyWords = {
	"frost",
	"cold",
	"ice"
};

OneHitWonder_NotFrostSpells = {
	--"frost nova", -- should this be here or in frost spells? we can't do anything, so...
	"frost armor",
	"frost shock", -- thottbot says nothing about frost damage, so...
	"frost ward",
	"ice armor", -- not entirely true
	"ice barrier", -- not entirely true
	"frost resistance totem",
	"frost resistance aura"
};



if ( GetLocale() == "frFR" ) then
elseif ( GetLocale() == "deDE" ) then
end
